/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2016 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*     Internet: segger.com   Support: support_embos@segger.com       *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.16                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Renesas RZ1 R7S72100 CPU board GENMAI
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define PORT4_BASE_ADDR    (0xFCFE3000)
#define LEDPORT_BASE_ADDR  (PORT4_BASE_ADDR)
#define LED0_BIT           (10)  /* User LED1, active low  */
#define LED1_BIT           (11)  /* User LED2, active low  */

#define LEDPORT_P          (*(volatile unsigned short*) (LEDPORT_BASE_ADDR + 0x0010u))
#define LEDPORT_PM         (*(volatile unsigned short*) (LEDPORT_BASE_ADDR + 0x0310u))
#define LEDPORT_PMC        (*(volatile unsigned short*) (LEDPORT_BASE_ADDR + 0x0410u))
#define LEDPORT_PIPC       (*(volatile unsigned short*) (LEDPORT_BASE_ADDR + 0x4210u))

#define LED0_MASK          (1uL << LED0_BIT)
#define LED1_MASK          (1uL << LED1_BIT)
#define LEDMASK_ALL        (LED0_MASK | LED1_MASK)
#define LED_NUM_LEDS       (2)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_PMC  &= ~(LEDMASK_ALL);     /* Enable Port           */
  LEDPORT_P    |= LEDMASK_ALL;        /* Initially all LEDs off  */
  LEDPORT_PM   &= ~(LEDMASK_ALL);     /* Initially clear LEDs    */
  LEDPORT_PIPC &= ~(LEDMASK_ALL);     /* Initially clear LEDs    */
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < LED_NUM_LEDS) {
    LEDPORT_P &= ~(1uL << (LED0_BIT + Index));  /* Switch on LED, active low */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < LED_NUM_LEDS) {
    LEDPORT_P |= (1uL << (LED0_BIT + Index));   /* Switch off LED */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < LED_NUM_LEDS) {
    LEDPORT_P ^= (1uL << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_CACHE_CleanRange()
*/
void BSP_CACHE_CleanRange (void * p, unsigned NumBytes) {
  OS_ARM_DCACHE_CleanRange(p, NumBytes);
}

/*********************************************************************
*
*       BSP_CACHE_InvalidateRange()
*/
void BSP_CACHE_InvalidateRange(void * p, unsigned NumBytes) {
  OS_ARM_DCACHE_InvalidateRange(p, NumBytes);
}

/****** End Of File *************************************************/
